@@ -5,7 +5,7 @@ use warnings;
 
 use base "System::Info::Base";
 
-our $VERSION = "0.052";
+our $VERSION = "0.054";
 
 =head1 NAME
 
@@ -52,15 +52,17 @@ sub _file_info {
 	m/\S/ or next;
 	s/^\s+//;
 	s/\s+$//;
-	if (my ($k, $v) = (m/^(.*\S)\s*=\s*(\S.*)$/)) {
+	if (my ($k, $v) = (m/^\s*(.*\S)\s*=\s*(\S.*?)\s*$/)) {
 	    # Having a value prevails over being defined
 	    defined $os->{$k} and next;
 	    $v =~ s/^"\s*(.*?)\s*"$/$1/;
+	    $v =~ s/^'\s*(.*?)\s*'$/$1/;
 	    $v =~ m{^["(]?undef(?:ined)?[")]$}i and $v = "undefined";
 	    $os->{$k} = $v;
 	    next;
 	    }
-	m/^[12][0-9]{3}(?:,\s*[12][0-9]{3})*$/ and next; # Copyright years
+	m/^[12][0-9]{3}(?:,\s*[12][0-9]{3})*(?:\s*,\s*)*$/ and next; # Copyright years
+	m/^[12][0-9]{3}(?:,\s*[12][0-9]{3})*.*All rights reserved/i and next; # Copyright years
 	exists $os->{$_} or $os->{$_} = undef;
 	}
     close $fh;
@@ -131,6 +133,10 @@ sub prepare_os {
 	    $distro .= " $os{DISTRIB_RELEASE}";
 	    }
 	}
+    elsif ($os{DISTRIBVER} && defined $os{NETBSD_OFFICIAL_RELEASE}) { # NetBSD 9
+	my @k = grep m/^netbsd\s+\d/i => keys %os;
+	($distro = @k == 1 ? $k[0] : "NetBSD $os{DISTRIBVER}") =~ s{/.*}{};
+	}
     elsif ($os{PRETTY_NAME}) {
 	$distro = $os{PRETTY_NAME};          # "openSUSE 12.1 (Asparagus) (x86_64)"
 	if (my $vid = $os{VERSION_ID}) {     # wheezy 7 => 7.2
@@ -276,9 +282,23 @@ sub linux_generic {
     # ::diag"Np: $n_phys_id, NC: $n_core_id, NP: $n_processor, NC: $n_cpu";
     $self->{__cpu_count} = $n_cpu;
 
-    my @parts = ("model name", "vendor_id", "cpu mhz");
-    my %info = map { ($_ => $self->from_cpuinfo ($_)) } @parts;
-    $self->{__cpu} = sprintf "%s (%s %.0fMHz)", map { $info{$_} } @parts;
+    {	my @tags = ("model name", "vendor_id", "cpu mhz");
+	my %info = map { ($_ => $self->from_cpuinfo ($_)) } @tags;
+	unless (defined $info{$tags[0]}) {
+	    # riscv64 -> rv64imafdc
+	    $info{$tags[0]} = $self->from_cpuinfo ("isa");
+	    }
+	$info{$tags[2]} and $info{$tags[2]} = sprintf "%.0fMHz", $info{$tags[2]};
+	my @cpui;
+	if ($info{$tags[0]}) {
+	    push @cpui => $info{shift @tags};
+	    push @cpui => "(".(join " " => grep { length } @info{@tags}).")";
+	    }
+	else {
+	    push @cpui =>                  grep { length } @info{@tags};
+	    }
+	$self->{__cpu} = join " " => @cpui;
+	}
 
     if ($n_phys_id) {
 	$n_processor > $n_phys_id and
@@ -363,14 +383,14 @@ sub linux_ppc {
 
     $self->{__cpu_count} = $self->count_in_cpuinfo (qr/^processor\s+:\s+/);
 
-    my @parts = qw( cpu machine clock );
-    my %info = map { ($_ => $self->from_cpuinfo ($_)) } @parts;
+    my @tags = qw( cpu machine clock );
+    my %info = map { ($_ => $self->from_cpuinfo ($_)) } @tags;
     if ($info{detected} = $self->from_cpuinfo ("detected as")){
 	$info{detected} =~ s/.*(\b.+Mac G\d).*/$1/;
 	$info{machine} = $info{detected};
 	}
 
-    $self->{__cpu} = sprintf "%s %s (%s)", map { $info{$_} } @parts;
+    $self->{__cpu} = sprintf "%s %s (%s)", map { $info{$_} } @tags;
     } # linux_ppc
 
 =head2 $si->linux_sparc
@@ -394,9 +414,9 @@ sub linux_sparc {
 
     $self->{__cpu_count} = $self->from_cpuinfo ("ncpus active");
 
-    my @parts = qw( cpu Cpu0ClkTck );
-    my %info  = map { ($_ => $self->from_cpuinfo ($_)) } @parts;
-    my $cpu   = $info{cpu};
+    my @tags = qw( cpu Cpu0ClkTck );
+    my %info = map { ($_ => $self->from_cpuinfo ($_)) } @tags;
+    my $cpu  = $info{cpu};
     $info{Cpu0ClkTck} and
 	$cpu .=  sprintf " (%.0fMHz)", hex ($info{Cpu0ClkTck}) / 1_000_000;
     $self->{__cpu} = $cpu;
@@ -498,7 +518,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-(c) 2016-2022, Abe Timmerman & H.Merijn Brand, All rights reserved.
+(c) 2016-2024, Abe Timmerman & H.Merijn Brand, All rights reserved.
 
 With contributions from Jarkko Hietaniemi, Campo Weijerman, Alan Burlison,
 Allen Smith, Alain Barbet, Dominic Dunlop, Rich Rauenzahn, David Cantrell.
